@@ -406,7 +406,7 @@ pub fn path_with_stem_suffix(path: &Path, suffix: &str) -> PathBuf {
 #[cfg(test)]
 mod tests {
   use super::*;
-  use tempfile::TempDir;
+  use test_util::TempDir;
 
   #[test]
   fn resolve_from_cwd_child() {
@@ -548,7 +548,7 @@ mod tests {
     //     ├── g.d.ts
     //     └── .gitignore
 
-    let t = TempDir::new().expect("tempdir fail");
+    let t = TempDir::new();
 
     let root_dir_path = t.path().join("dir.ts");
     let root_dir_files = ["a.ts", "b.js", "c.tsx", "d.jsx"];
@@ -609,7 +609,7 @@ mod tests {
     //     ├── g.d.ts
     //     └── .gitignore
 
-    let t = TempDir::new().expect("tempdir fail");
+    let t = TempDir::new();
 
     let root_dir_path = t.path().join("dir.ts");
     let root_dir_files = ["a.ts", "b.js", "c.tsx", "d.jsx"];
