@@ -3,6 +3,7 @@
 use crate::colors;
 use crate::file_fetcher::get_source_from_data_url;
 use crate::flags::Flags;
+use crate::fmt_errors::format_js_error;
 use crate::ops;
 use crate::proc_state::ProcState;
 use crate::version;
@@ -293,7 +294,7 @@ pub async fn run(
     root_cert_store: Some(root_cert_store),
     seed: metadata.seed,
     source_map_getter: None,
-    js_error_create_fn: None,
+    format_js_error_fn: Some(Arc::new(format_js_error)),
     create_web_worker_cb,
     web_worker_preload_module_cb,
     maybe_inspector_server: None,
@@ -305,6 +306,7 @@ pub async fn run(
     broadcast_channel,
     shared_array_buffer_store: None,
     compiled_wasm_module_store: None,
+    stdio: Default::default(),
   };
   let mut worker = MainWorker::bootstrap_from_options(
     main_module.clone(),
