@@ -1610,6 +1610,11 @@ itest!(worker_drop_handle_race {
   exit_code: 1,
 });
 
+itest!(worker_drop_handle_race_terminate {
+  args: "run --unstable worker_drop_handle_race_terminate.js",
+  output: "worker_drop_handle_race_terminate.js.out",
+});
+
 itest!(worker_close_nested {
   args: "run --quiet --reload --allow-read worker_close_nested.js",
   output: "worker_close_nested.js.out",
@@ -2764,3 +2769,8 @@ itest!(report_error_handled {
   args: "run --quiet report_error_handled.ts",
   output: "report_error_handled.ts.out",
 });
+
+itest!(spawn_stdout_inherit {
+  args: "run --quiet --unstable -A spawn_stdout_inherit.ts",
+  output: "spawn_stdout_inherit.ts.out",
+});
