@@ -5,7 +5,6 @@ use crate::flags::CoverageFlags;
 use crate::flags::Flags;
 use crate::fs_util::collect_files;
 use crate::proc_state::ProcState;
-use crate::source_maps::SourceMapGetter;
 use crate::tools::fmt::format_json;
 
 use deno_ast::MediaType;
@@ -14,10 +13,11 @@ use deno_core::anyhow::anyhow;
 use deno_core::anyhow::Context;
 use deno_core::error::AnyError;
 use deno_core::serde_json;
+use deno_core::sourcemap::SourceMap;
 use deno_core::url::Url;
 use deno_core::LocalInspectorSession;
+use deno_core::SourceMapGetter;
 use regex::Regex;
-use sourcemap::SourceMap;
 use std::fs;
 use std::fs::File;
 use std::io::BufWriter;
